@@ -6,6 +6,7 @@ import (
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/aws"            //nolint:staticcheck
+	"github.com/aws/aws-sdk-go/aws/awserr"     //nolint:staticcheck
 	"github.com/aws/aws-sdk-go/service/acmpca" //nolint:staticcheck
 
 	"github.com/ekristen/libnuke/pkg/registry"
@@ -34,7 +35,6 @@ func (l *ACMPCACertificateAuthorityLister) List(_ context.Context, o interface{}
 	svc := acmpca.New(opts.Session)
 
 	var resources []resource.Resource
-	var tags []*acmpca.Tag
 
 	params := &acmpca.ListCertificateAuthoritiesInput{
 		MaxResults: aws.Int64(100),
@@ -52,9 +52,16 @@ func (l *ACMPCACertificateAuthorityLister) List(_ context.Context, o interface{}
 				MaxResults:              aws.Int64(100),
 			}
 
+			tags := []*acmpca.Tag{}
 			for {
 				tagResp, tagErr := svc.ListTags(tagParams)
+
 				if tagErr != nil {
+					if awsTagErr, ok := err.(awserr.Error); ok {
+						if awsTagErr.Code() == acmpca.ErrCodeInvalidStateException {
+							break
+						}
+					}
 					return nil, tagErr
 				}
 
